@@ -2,7 +2,7 @@
 from sqlbean.db.query import Query, escape
 from sqlbean.db.mc_connection import mc
 from marshal import dumps, loads
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get, __eq__, __nq__
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get, __eq__, __ne__
 from array import array
 from datetime import datetime
 
@@ -29,7 +29,7 @@ class McModel(object):
     debug = False
     get_or_create = get_or_create
     __eq__ = __eq__
-    __nq__ = __nq__
+    __ne__ = __ne__
 
     def __init__(self, *args, **kwargs):
         'Allows setting of fields using kwargs'
@@ -43,13 +43,14 @@ class McModel(object):
 
     @classmethod
     def mc_get(cls, id):
-        key = cls.Meta.mc_key%id
-        value = mc.get_marshal(key, cls._loads)
-        if value is None:
-            value = cls.get(id)
-            if value:
-                value.mc_set()
-        return value
+        if id:
+            key = cls.Meta.mc_key%id
+            value = mc.get_marshal(key, cls._loads)
+            if value is None:
+                value = cls.get(id)
+                if value:
+                    value.mc_set()
+            return value
 
     @classmethod
     def mc_flush_multi(cls, id_list):
@@ -193,7 +194,7 @@ class McModel(object):
         query = 'DELETE FROM %s WHERE `%s` = %%s' % (self.Meta.table_safe, self.Meta.pk)
         values = [getattr(self, self.Meta.pk)]
         Query.raw_sql(query, values, self.db)
-        self.mc_delete(id)
+        self.mc_flush()
 
     def update(self, **kwds):
         set_what = ','.join(
