@@ -1,6 +1,6 @@
 #coding:utf-8
 from sqlbean.db.query import Query, escape
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get , __eq__, __nq__
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get , __eq__, __ne__
 
 class Model(object):
     '''
@@ -73,7 +73,7 @@ class Model(object):
     '''
     __metaclass__ = ModelBase
     __eq__ = __eq__
-    __nq__ = __nq__
+    __ne__ = __ne__
     debug = False
 
     def __init__(self, *args, **kwargs):
@@ -129,8 +129,8 @@ class Model(object):
         'Uses SQL INSERT to create new record'
         # if pk field is set, we want to insert it too
         # if pk field is None, we want to auto-create it from lastrowid
-	pk = self._get_pk()
-	auto_pk = 1 and (pk is None) or 0
+        pk = self._get_pk()
+        auto_pk = 1 and (pk is None) or 0
         fields = [
             f for f in self._fields
             if f != self.Meta.pk or not auto_pk
@@ -140,7 +140,7 @@ class Model(object):
         values = []
         for i in fields:
             v = getattr(self, i, None)
-	    #print i,v
+            #print i,v
             if v is not None:
                 used_fields.append(escape(i))
                 values.append(v)
@@ -149,8 +149,8 @@ class Model(object):
                 ', '.join(["%s"] * len(used_fields))
         )
         cursor = Query.raw_sql(query, values, self.db)
-	
-	
+
+
 
         if pk is None:
             self._set_pk(cursor.lastrowid)
